summary refs log tree commit diff
path: root/gnu/installer.scm
diff options
context:
space:
mode:
Diffstat (limited to 'gnu/installer.scm')
-rw-r--r--gnu/installer.scm4
1 files changed, 2 insertions, 2 deletions
diff --git a/gnu/installer.scm b/gnu/installer.scm
index fd66359cbe..2ae139b13f 100644
--- a/gnu/installer.scm
+++ b/gnu/installer.scm
@@ -209,11 +209,11 @@ selected keymap."
           (compute (lambda _
                      (#$keymap-step current-installer))))
 
          ;; Run a partitionment tool allowing the user to modify
          ;; partition tables, partitions and their mount points.
          (installer-step
           (id 'partition)
-          (description (G_ "Partitionment"))
+          (description (G_ "Partitioning"))
           (compute (lambda _
                      ((installer-partition-page current-installer))))
           (configuration-formatter user-partitions->configuration))
@@ -209,11 +209,11 @@ selected keymap."
                      (#$keymap-step current-installer))))
 
-         ;; Run a partitionment tool allowing the user to modify
+         ;; Run a partitioning tool allowing the user to modify
          ;; partition tables, partitions and their mount points.
          (installer-step